@@ -5,8 +5,8 @@
 #' @export
 #' @keywords internal
 #' @examples
-#' benchplot(qplot(mpg, wt, data = mtcars))
-#' benchplot(qplot(mpg, wt, data = mtcars) + facet_grid(.~ cyl))
+#' benchplot(ggplot(mtcars, aes(mpg, wt)) + geom_point())
+#' benchplot(ggplot(mtcars, aes(mpg, wt)) + geom_point() + facet_grid(. ~ cyl))
 benchplot <- function(x) {
 
   construct <- system.time(force(x))
@@ -18,7 +18,7 @@ benchplot <- function(x) {
 
   times <- rbind(construct, build, render, draw)[, 1:3]
 
-  unrowname(data.frame(
+  plyr::unrowname(data.frame(
     step = c("construct", "build", "render", "draw", "TOTAL"),
     rbind(times, colSums(times))))
 }
