@@ -1,6 +1,6 @@
 # Prediction data frame
 # Get predictions with standard errors into data frame
-# 
+#
 # @keyword internal
 # @alias predictdf.default
 # @alias predictdf.glm
@@ -8,32 +8,32 @@
 # @alias predictdf.locfit
 predictdf <- function(model, xseq, se, level) UseMethod("predictdf")
 
-#' @S3method predictdf default
+#' @export
 predictdf.default <- function(model, xseq, se, level) {
-  pred <- stats::predict(model, newdata = data.frame(x = xseq), se = se,
-    level = level, interval = if(se) "confidence" else "none")
+  pred <- stats::predict(model, newdata = data.frame(x = xseq), se.fit = se,
+    level = level, interval = if (se) "confidence" else "none")
 
   if (se) {
     fit <- as.data.frame(pred$fit)
     names(fit) <- c("y", "ymin", "ymax")
-    data.frame(x = xseq, fit, se = pred$se)
+    data.frame(x = xseq, fit, se = pred$se.fit)
   } else {
     data.frame(x = xseq, y = as.vector(pred))
-  } 
+  }
 }
 
-#' @S3method predictdf glm
+#' @export
 predictdf.glm <- function(model, xseq, se, level) {
-  pred <- stats::predict(model, newdata = data.frame(x = xseq), se = se, 
+  pred <- stats::predict(model, newdata = data.frame(x = xseq), se.fit = se,
     type = "link")
-  
+
   if (se) {
-    std <- qnorm(level / 2 + 0.5)
+    std <- stats::qnorm(level / 2 + 0.5)
     data.frame(
-      x = xseq, 
+      x = xseq,
       y = model$family$linkinv(as.vector(pred$fit)),
-      ymin = model$family$linkinv(as.vector(pred$fit - std * pred$se)), 
-      ymax = model$family$linkinv(as.vector(pred$fit + std * pred$se)), 
+      ymin = model$family$linkinv(as.vector(pred$fit - std * pred$se)),
+      ymax = model$family$linkinv(as.vector(pred$fit + std * pred$se)),
       se = as.vector(pred$se)
     )
   } else {
@@ -41,13 +41,13 @@ predictdf.glm <- function(model, xseq, se, level) {
   }
 }
 
-#' @S3method predictdf loess
+#' @export
 predictdf.loess <- function(model, xseq, se, level) {
   pred <- stats::predict(model, newdata = data.frame(x = xseq), se = se)
 
   if (se) {
     y = pred$fit
-    ci <- pred$se.fit * qt(level / 2 + .5, pred$df)
+    ci <- pred$se.fit * stats::qt(level / 2 + .5, pred$df)
     ymin = y - ci
     ymax = y + ci
     data.frame(x = xseq, y, ymin, ymax, se = pred$se.fit)
@@ -56,10 +56,10 @@ predictdf.loess <- function(model, xseq, se, level) {
   }
 }
 
-#' @S3method predictdf locfit
+#' @export
 predictdf.locfit <- function(model, xseq, se, level) {
-  pred <- predict(model, newdata = data.frame(x = xseq), se.fit = se)
-                          
+  pred <- stats::predict(model, newdata = data.frame(x = xseq), se.fit = se)
+
   if (se) {
     y = pred$fit
     ymin = y - pred$se.fit
